@@ -1,3 +1,4 @@
+/* $Id: cursors.c,v 1.1 2004/08/28 19:25:45 dannybackx Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -33,6 +34,10 @@
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
+#include <LTconfig.h>
+
+#include <Xm/Xm.h>
+#include <Xm/MwmUtil.h>
 #include "mwm.h"
 
 #include <X11/cursorfont.h>
