@@ -1,8 +1,9 @@
 /**
  *
- * $Id: PopupUtil.h,v 1.1 1998/01/12 02:12:23 pgw Exp $
+ * $Id: PopupUtil.h,v 1.1 2004/08/28 19:23:36 dannybackx Exp $
  *
  * Copyright (C) 1998 Free Software Foundation, Inc.
+ * Copyright (C) 1998-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,27 +23,14 @@
  *
  **/
 
-#ifndef XM_POPUPUTIL_H
-#define XM_POPUPUTIL_H
+#ifndef _XMI_POPUPUTIL_H
+#define _XMI_POPUPUTIL_H
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-/* 
-  This routines attempt to be smart about placement of the shell 
-  on the display. 
-*/
-void XmeShellSmartPlacement(Widget w);
 /*
   These should be used instead of there Xt alternative.
 */
-void XmePopup(Widget w, XtGrabKind kind);
-void XmePopupSpringLoaded(Widget w);
-
-#ifdef __cplusplus
-}
-#endif
-
-#endif
+void _XmPopup(Widget w, XtGrabKind kind);
+void _XmPopupSpringLoaded(Widget w);
+void _XmPopdown(Widget w);
 
+#endif /* _XMI_POPUTIL_H */
