@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/LabelG.c,v 1.3 2004/09/27 17:44:43 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/LabelG.c,v 1.6 2005/03/22 14:48:04 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/LabelG.c,v 1.3 2004/09/27 17:44:43 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/LabelG.c,v 1.6 2005/03/22 14:48:04 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -270,7 +270,6 @@ static XtResource resources[] =
 	sizeof(XmString), Offset(_label),
 	XmRImmediate, (XtPointer)NULL
     },
-#if (XmVERSION > 1)
     {
 	/*
 	 * Note !!
@@ -282,27 +281,17 @@ static XtResource resources[] =
 	sizeof(Boolean), Offset(check_set_render_table),
 	XmRImmediate, (XtPointer)NULL
     },
-#endif
-#if (XmVERSION > 1)
     {
 	XmNfontList, XmCFontList, XmRFontList,
 	sizeof(XmFontList), Offset(font),
 	XmRCallProc, (XtPointer)_XmLabelGSetRenderTable
     },
-#else
-    {
-	XmNfontList, XmCFontList, XmRFontList,
-	sizeof(XmFontList), Offset(font),
-	XmRImmediate, (XtPointer)0
-    },
-#endif
-#if (XmVERSION > 1)
     {
 	XmNrenderTable, XmCRenderTable, XmRRenderTable,
 	sizeof(XmFontList), Offset(font),
 	XmRCallProc, (XtPointer)_XmLabelGSetRenderTable
     },
-#endif
+    /* End of fontlist / rendertable */
     {
 	XmNmnemonic, XmCMnemonic, XmRKeySym,
 	sizeof(KeySym), Offset(mnemonic),
@@ -1242,10 +1231,7 @@ MLM: WHY TRAVERSAL?
     /* if the user specified one, COPY it */
     else
     {
-	XmFontList	o = LabG_Font(new_w);
 	LabG_Font(new_w) = XmFontListCopy(LabG_Font(new_w));
-	if (o)
-		XmFontListFree(o);
     }
 
 
@@ -1624,10 +1610,7 @@ set_values(Widget old, Widget request, Widget new_w,
 	}
 	else
 	{
-	    XmFontList	o = LabG_Font(new_w);
 	    LabG_Font(new_w) = XmFontListCopy(LabG_Font(new_w));
-	    if (o)
-		    XmFontListFree(o);
 	}
 
 	refresh_needed = True;
@@ -2409,7 +2392,6 @@ _XmLabelGSetRenderTable(Widget w, int o, XrmValue *v)
 {
 	XmLabelGadget	lw = (XmLabelGadget)w;
 
-#if (XmVERSION > 1)
 	DEBUGOUT(_LtDebug(__FILE__, w, "_XmLabelGSetRenderTable (%d) Font was %p\n",
 		lw->label.check_set_render_table, lw->label.font));
 
@@ -2418,20 +2400,8 @@ _XmLabelGSetRenderTable(Widget w, int o, XrmValue *v)
 		 * This is the second time we're getting called.
 		 * Therefore the result is undefined.
 		 */
-#if 0
-		v->addr = NULL;	/* FIX ME or should we pass nothing ? */
-#endif
-#if 0
-	/* Don't generate a warning here, not even in LESSTIF_VERBOSE.
-	 * - this is really too much */
-		_XmWarning(w, "Shouldn't set both XmNfontList and XmNrenderTable\n");
-#endif
 	} else {
 		v->addr = (char *)&(lw->label.font);
 		lw->label.check_set_render_table = True;
 	}
-#else
-	/* Motif 1.x */
-	v->addr = (char *)&(lw->label.font);
-#endif
 }
