@@ -47,7 +47,19 @@ main(int argc, char **argv)
   XtVaGetValues(one, XmNshadowThickness, &thick, NULL);
   printf("shadow thickness: %d\n", thick);
 
-  XtAppMainLoop(app);
 
+/* Note: the following values are the result of
+ * querying the current geometry.
+ */
+{
+static XtWidgetGeometry Expected[] = {
+   CWWidth | CWHeight            ,  415,  430,   55,   38, 0,0,0, /* One */
+   CWWidth | CWHeight | CWX | CWY,   10,   10,   34,   17, 0,0,0, /* test1 */
+   CWWidth | CWHeight | CWX | CWY,   10,   10,   34,   17, 0,0,0, /* test2 */
+};
+/* toplevel should be replaced with to correct applicationShell */
+PrintDetails(toplevel, Expected);
+}
+LessTifTestMainLoop(toplevel);
   exit(0);
 }
