@@ -1,15 +1,20 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/form/test3.c,v 1.7 2002/05/01 15:39:21 amai Exp $ */
 /**
  *
  * form1.c
  *
  **/
 
+#include <stdlib.h>
 #include <stdio.h>
+
 #include <Xm/Xm.h>
 #include <Xm/PushB.h>
 #include <Xm/PushBG.h>
 #include <Xm/Form.h>
 
+#include "../../common/Test.h"
+
 
 int
 main(int argc, char **argv)
@@ -43,9 +48,9 @@ main(int argc, char **argv)
 
   {
   static XtWidgetGeometry Expected[] = {
-  	CWWidth | CWHeight,              0,  0, 72, 25, 0,0,0,	/* Form */
-  	CWWidth | CWHeight | CWX | CWY, 42,  0, 30, 25, 0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,  0,  0, 42, 25, 0,0,0,	/* two */
+  	{CWWidth | CWHeight,              0,  0, 72, 25, 0,0,0,	/* Form */},
+  	{CWWidth | CWHeight | CWX | CWY, 42,  0, 30, 25, 0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,  0,  0, 42, 25, 0,0,0,	/* two */},
 };
 
   PrintDetails(toplevel, Expected);
