@@ -1,6 +1,8 @@
-/* menu.c */
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/rowcolumn/test32.c,v 1.7 2001/05/23 14:21:12 amai Exp $ */
 
+#include <stdlib.h>
 #include <stdio.h>
+
 #include <X11/Intrinsic.h>
 
 #include <Xm/Xm.h>
@@ -44,7 +46,7 @@ void createOptionMenu(Widget parent)
   XtVaSetValues(optionMenu,
 		XmNtopAttachment, XmATTACH_WIDGET,
 		XmNtopWidget, mainMenu,
-		0);
+		NULL);
 }
 
 int main(int argc, char *argv[])
@@ -93,7 +95,7 @@ Widget GXCreateOptionMenu(Widget parent, char **entries)
     cptr++;    
   } while (*cptr);
 
-  if (!(buttonArray=malloc(cnt*sizeof(XmString)))) {
+  if (!(buttonArray=(XmString*)malloc(cnt*sizeof(XmString)))) {
     return NULL;
   }
 
@@ -123,7 +125,7 @@ void layoutApplication(Widget topLevel)
   /* note, later this will be a list of queries */
   topForm = XtVaCreateManagedWidget("topForm",
 				    xmFormWidgetClass, topLevel,
-				    0);
+				    NULL);
   
   createOptionMenu(topForm);
 
@@ -135,6 +137,6 @@ void layoutApplication(Widget topLevel)
 		XmNtopWidget, mainMenu,
 		XmNleftAttachment, XmATTACH_WIDGET,
 		XmNleftWidget, optionMenu,
-		0);
+		NULL);
 
 }
