@@ -1,4 +1,5 @@
-/*
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/text/test11.c,v 1.7 2001/05/22 11:19:05 amai Exp $
+
    From:        Yasushi Yamasaki <yamapu@osk3.3web.ne.jp>
    To:          lesstif@hungry.com
    Subject:     bug report
@@ -6,12 +7,14 @@
    Cc:          yamapu@osk3.3web.ne.jp
  */
 
-/* test1.c */
+#include <stdlib.h>
+#include <stdio.h>
 #include <unistd.h>
 #include <Xm/Xm.h>
 #include <Xm/Text.h>
 
-void 
+
+int
 main(int argc, char *argv[])
 {
     XtAppContext app;
@@ -19,27 +22,26 @@ main(int argc, char *argv[])
     void *before;
     void *after;
     int iter = 0;
-    int diff = 0;
-    int total = 0;
+    long diff, total = 0;
 
     shell = XtAppInitialize(&app, "Test", NULL, 0,
 			    &argc, argv, NULL, NULL, 0);
-    while (iter < 10000)
+    while (iter < 100)
     {
 	before = sbrk((ptrdiff_t) 0);
 	w = XtCreateWidget("name", xmTextWidgetClass, shell, NULL, 0);
 	XtDestroyWidget(w);
 	after = sbrk((ptrdiff_t) 0);
-	if ((int)after - (int)before > 0)
+	diff = (long)((char *)after-(char *)before);
+	if (diff > 0)
 	{
 	    if (iter != 0)
 	    {
 		/*
 		printf("%i %i %p %i\n", iter, iter - diff, after - before, (after - before) / (iter - diff));
 		*/
-		total += (int)after - (int)before;
+		total += diff;
 	    }
-	    diff = iter;
 	}
 	iter++;
     }
